searchData={"items":[{"type":"module","title":"DomainTwistex","doc":"DomainTwistEx provides domain permutation generation using Rust NIFs.","ref":"DomainTwistex.html"},{"type":"module","title":"Prerequisites - DomainTwistex","doc":"- Rust and Cargo must be installed on your system\n  Install from https://rustup.rs/\n\nIf you see a `:enoent` error during compilation, ensure Rust/Cargo is installed\nand available in your PATH.","ref":"DomainTwistex.html#module-prerequisites"},{"type":"function","title":"DomainTwistex.analyze_domain/2","doc":"Analyzes a domain by generating permutations and checking them concurrently.","ref":"DomainTwistex.html#analyze_domain/2"},{"type":"function","title":"Parameters - DomainTwistex.analyze_domain/2","doc":"* domain - The base domain string to analyze\n  * opts - Optional keyword list of settings:\n    * max_concurrency: Maximum number of concurrent tasks (default: System.schedulers_online() * 2)\n    * timeout: Timeout in milliseconds for each task (default: 2000)\n    * ordered: Whether results should maintain order (default: false)","ref":"DomainTwistex.html#analyze_domain/2-parameters"},{"type":"function","title":"Returns - DomainTwistex.analyze_domain/2","doc":"List of successful domain check results","ref":"DomainTwistex.html#analyze_domain/2-returns"},{"type":"function","title":"Examples - DomainTwistex.analyze_domain/2","doc":"```\n  iex(2)> DomainTwistex.analyze_domain(\"google.com\")\n  [\n    %{\n       kind: \"Tld\",\n       fqdn: \"google.co.uz\",\n       ip_addresses: [\"173.194.219.99\", \"173.194.219.103\", \"173.194.219.147\",\n       \"173.194.219.104\", \"173.194.219.105\", \"173.194.219.106\"],\n       mx_records: [%{priority: 0, server: \".\"}],\n       resolvable: true,\n       tld: \"co.uz\"\n       },\n    %{\n      kind: \"Bitsquatting\",\n      fqdn: \"gooogle.com\",\n      ip_addresses: [\"64.233.185.104\", \"64.233.185.106\", \"64.233.185.99\",\n      \"64.233.185.147\", \"64.233.185.105\", \"64.233.185.103\"],\n      mx_records: [%{priority: 0, server: \".\"}],\n      resolvable: true,\n      tld: \"com\"\n      },...]\n      \n  ```","ref":"DomainTwistex.html#analyze_domain/2-examples"},{"type":"function","title":"DomainTwistex.generate_permutations/1","doc":"Generates domain permutations using the Twistrs Rust library.\n\nThis function is implemented as a Native Implemented Function (NIF) that interfaces \nwith the Twistrs Rust library for efficient domain permutation generation.\nThe actual implementation is in Rust and loaded at runtime.","ref":"DomainTwistex.html#generate_permutations/1"},{"type":"function","title":"Attribution - DomainTwistex.generate_permutations/1","doc":"This NIF wraps functionality from the Twistrs library:\nhttps://github.com/haveibeensquatted/twistrs","ref":"DomainTwistex.html#generate_permutations/1-attribution"},{"type":"function","title":"Prerequisites - DomainTwistex.generate_permutations/1","doc":"Requires:\n- Rust toolchain installed (rustc, cargo)\n- Proper NIF compilation setup in mix.exs\n- `native/domaintwistex` Rust project properly configured","ref":"DomainTwistex.html#generate_permutations/1-prerequisites"},{"type":"function","title":"Parameters - DomainTwistex.generate_permutations/1","doc":"* domain - String representing the domain to generate permutations for","ref":"DomainTwistex.html#generate_permutations/1-parameters"},{"type":"function","title":"Returns - DomainTwistex.generate_permutations/1","doc":"List of generated domain permutation strings","ref":"DomainTwistex.html#generate_permutations/1-returns"},{"type":"function","title":"Examples - DomainTwistex.generate_permutations/1","doc":"```\n   iex(1)> DomainTwistex.generate_permutations(\"google.com\")\n   [ %{kind: \"Keyword\", fqdn: \"servicegoogle.com\", tld: \"com\"},\n   %{kind: \"Homoglyph\", fqdn: \"ğöögle.com\", tld: \"com\"},\n   %{kind: \"Homoglyph\", fqdn: \"ğöogle.com\", tld: \"com\"},\n   %{kind: \"Tld\", fqdn: \"google.cc\", tld: \"cc\"},\n   %{kind: \"Homoglyph\", fqdn: \"ğoơgle.com\", tld: \"com\"},\n   %{kind: \"Homoglyph\", fqdn: \"goóglë.com\", tld: \"com\"}, ...]\n   ```","ref":"DomainTwistex.html#generate_permutations/1-examples"},{"type":"function","title":"Runtime - DomainTwistex.generate_permutations/1","doc":"This function will raise an error if:\n- The NIF library fails to load\n- Rust/Cargo is not installed during compilation","ref":"DomainTwistex.html#generate_permutations/1-runtime"},{"type":"function","title":"DomainTwistex.get_live_mx_domains/2","doc":"Filters domains to return only those with valid MX records.","ref":"DomainTwistex.html#get_live_mx_domains/2"},{"type":"function","title":"Parameters - DomainTwistex.get_live_mx_domains/2","doc":"* domain - The domain to analyze","ref":"DomainTwistex.html#get_live_mx_domains/2-parameters"},{"type":"function","title":"Returns - DomainTwistex.get_live_mx_domains/2","doc":"List of domain results that have non-empty MX records","ref":"DomainTwistex.html#get_live_mx_domains/2-returns"},{"type":"function","title":"Examples - DomainTwistex.get_live_mx_domains/2","doc":"```\n   iex(3)> DomainTwistex.get_live_mx_domains(\"google.com\", max_concurrency: 50)\n   [%{\n      kind: \"Tld\",\n      mx_records: [%{priority: 0, server: \"smtp.google.com\"}],\n      fqdn: \"google.lt\",\n      resolvable: true,\n      ip_addresses: [\"172.217.215.94\"],\n      tld: \"lt\"\n      },\n      %{\n      kind: \"Tld\",\n      mx_records: [%{priority: 0, server: \"smtp.google.com\"}],\n      fqdn: \"google.rs\",\n      resolvable: true,\n      ip_addresses: [\"142.250.9.94\"],\n      tld: \"rs\"\n      },...]\n```","ref":"DomainTwistex.html#get_live_mx_domains/2-examples"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}